@@ -8,8 +8,8 @@ use core::mem::{size_of, transmute, transmute_copy};
 use cortex_m::prelude::*;
 use stm32f1xx_hal_bxcan::delay::Delay;
 use eeprom24x::Eeprom24x;
-use eeprom24x::page_size::B8;
-use eeprom24x::addr_size::OneByte;
+use eeprom24x::page_size::B32;
+use eeprom24x::addr_size::TwoBytes;
 
 use ross_config::event_processor::EventProcessor;
 use ross_config::matcher::*;
@@ -29,16 +29,16 @@ pub struct DeviceInfo {
 
 #[derive(Debug)]
 pub struct Eeprom<I2C, PS, AS> {
-    driver: Eeprom24x<I2C, PS, AS,>,
+    driver: Eeprom24x<I2C, PS, AS>,
     device_info_address: u32,
 }
 
 pub type EepromError = eeprom24x::Error<nb::Error<stm32f1xx_hal_bxcan::i2c::Error>>;
 
-impl<I2C> Eeprom<I2C, B8, OneByte> where
+impl<I2C> Eeprom<I2C, B32, TwoBytes> where
     I2C: _embedded_hal_blocking_i2c_WriteRead<Error = nb::Error<stm32f1xx_hal_bxcan::i2c::Error>> + _embedded_hal_blocking_i2c_Write<Error = nb::Error<stm32f1xx_hal_bxcan::i2c::Error>>,
 {
-    pub fn new(driver: Eeprom24x<I2C, B8, OneByte>, device_info_address: u32) -> Self {
+    pub fn new(driver: Eeprom24x<I2C, B32, TwoBytes>, device_info_address: u32) -> Self {
         Self {
             driver,
             device_info_address,
@@ -445,7 +445,15 @@ impl<I2C> Eeprom<I2C, B8, OneByte> where
     }
 
     fn write_producer_to_vec(data: &mut Vec<u8>, producer: &Box<dyn Producer>) {
-        if let Some(producer) = producer.downcast_ref::<BcmChangeBrightnessProducer>() {
+        if let Some(producer) = producer.downcast_ref::<NoneProducer>() {
+            Self::write_u16_to_vec(data, NONE_PRODUCER_CODE);
+
+            unsafe {
+                for byte in transmute_copy::<NoneProducer, [u8; size_of::<NoneProducer>()]>(producer).iter() {
+                    data.push(*byte);
+                }
+            }
+        } else if let Some(producer) = producer.downcast_ref::<BcmChangeBrightnessProducer>() {
             Self::write_u16_to_vec(data, BCM_CHANGE_BRIGHTNESS_PRODUCER_CODE);
 
             unsafe {
